#!/bin/bash

TMPDIR='/tmp/.rdor4'
B="$TMPDIR/comprueba-rdor4"
INTERVMDELAY=0

SEP="------------------------------------------------------------------"

START=$(date +%s)
mkdir -p $TMPDIR
rm -rf $TMPDIR/*

HOSTNAME=$( hostname )
#HOSTNAME=l351
echo "Hostname=$HOSTNAME"

case "$HOSTNAME" in
    rdor-vm )
       echo "Escenario corriendo en maquina virtual" 

       # Configuramos VPN y arrancamos tinc
       echo "tar xfvz pop.tgz"
       tar xfvz pop.tgz
       #sudo killall tincd
       sudo /etc/init.d/tinc stop
       sudo rm -rf /etc/tinc/*
       sudo mv pop?ra??/* /etc/tinc

       # add pop?server addresses to /etc/hosts
       ALREADYINHOSTS=$( cat /etc/hosts | grep pop1server )

       if [ -z "$ALREADYINHOSTS" ]; then
          echo "Adding popXserver entries to /etc/hosts"
          sudo sh -c 'echo "138.4.24.48     pop1server pop2server pop3server pop4server pop5server pop6server" >> /etc/hosts'
       else
          echo "popXserver entries already in /etc/hosts"
       fi

       sudo /etc/init.d/tinc restart

       # Descomprimimos escenario
       echo "unzip -o -d $TMPDIR rdor*.zip"
       unzip -o -d $TMPDIR rdor*.zip

       SCENARIO=$( ls $TMPDIR/rdor4*/*.xml | grep -v conf)

       ;;

    l[0-9][0-9][0-9] ) 
       echo "Escenario corriendo en el laboratorio ($HOSTNAME)"

       # Descomprimimos escenario
       echo "unzip -o -d $TMPDIR rdor*.zip"
       unzip -o -d $TMPDIR rdor*.zip

       SCENARIO=$( ls $TMPDIR/rdor4*/*.xml | grep -v conf)

       POP=$( cat $SCENARIO | sed -n '/net="pop"/{n;p}' | sed -e 's/.*>10\.\(.*\)0\.0.*<.*/\1/')
       ASN=$( cat $SCENARIO | sed -n '/net="pop"/{n;p}' | sed -e 's/.*>10\.[0-9]\+\.[0-9]\+\.\(.*\)<.*/\1/' )

       echo "POP=$POP"
       echo "ASN=$ASN"

       OLDLINE="<net name=\"pop\" mode=\"virtual_bridge\" type=\"lan\" external=\"pop${POP}net\"/>"
       NEWLINE="<net name=\"pop\" mode=\"virtual_bridge\" type=\"lan\" external=\"eth1\" vlan=\"70${POP}\"/>"
       sed -i -e "s#$OLDLINE#$NEWLINE#" $SCENARIO

       ;;

    * ) 

    echo "ERROR: Ordenador desconocido"
    exit 1
esac


# Creamos script comprueba-rdor4
cat > $B << "FIN-B"
#!/bin/bash

RETRYCHECKVM=5
RETRYCHECKDELAY=5

echo "Comprobando arranque de routers y hosts..."
VMS="A B C D E H1 H2"
echo $VMS

for VM in $VMS; do

  echo "$VM:"
  for ((i=$RETRYCHECKVM; i>0; i--)); do
    #echo "nmap -p ssh $VM | grep ssh | grep open"
    RES=$( nmap -p ssh $VM | grep ssh | grep open )
    #echo "$i - RES=$RES"
    if [ "$RES" != "" ]; then
      echo " arrancado"
      break
    elif [ "$i" -eq 1 ]; then
      echo "ERROR"
      FALLOS="$FALLOS $VM"
      break
    fi
    echo " x"
    sleep $RETRYCHECKDELAY
  done
done

echo $SEP
if [ "$FALLOS" = "" ]; then
    echo "Escenario arrancado correctamente."
else
    echo "ERROR: algunos sistemas no arrancaron correctamente ($FALLOS )"
    echo "       Rearranque el escenario de nuevo"
fi
echo $SEP

FIN-B

function limpia () {

# Hacemos limpieza primero...
#PIDS=$( ps uaxww | grep "kernels/linux" | grep -v grep | awk '{ print $2 }' )
#if [ "$PIDS" ]; then
#    echo "Matando procesos UML linux:" $PIDS
#    sudo kill -9 $PIDS
#else
#    echo "No hay procesos linux"
#fi

PIDS=$( ps uaxww | grep "sudo vnx" | grep -v grep | awk '{ print $2 }' )
if [ "$PIDS" ]; then
    echo "Matando procesos vnx:" $PIDS
    sudo kill -9 $PIDS
else
    echo "No hay procesos vnx"
fi

#PIDS=$( ps uaxww | grep "mconsole" | grep -v grep | awk '{ print $2 }' )
#if [ "$PIDS" ]; then
#    echo "Matando procesos mconsole:" $PIDS
#    sudo kill -9 $PIDS
#else
#    echo "No hay procesos mconsole"
#fi

PIDS=$( ps uaxww | grep "comprueba-rdor4" | grep -v grep | awk '{ print $2 }' )
if [ "$PIDS" ]; then
    echo "Matando procesos comprueba-rdor4:" $PIDS
    sudo kill -9 $PIDS
else
    echo "No hay procesos comprueba-rdor4"
fi

#PIDS=$( ps uaxww | grep "nmap" | grep -v grep | awk '{ print $2 }' )
#if [ "$PIDS" ]; then
#    echo "Matando procesos nmap:" $PIDS
#    sudo kill -9 $PIDS
#else
#    echo "No hay procesos nmap"
#fi

#sudo vnx -D
sudo vnx -f $SCENARIO -v -P -D

}

( limpia; sudo vnx -f $SCENARIO -v -t --intervm-delay $INTERVMDELAY; echo ''; echo "$SEP"; echo ''; bash $B; echo "$SEP"; END=$(date +%s); DIFF=$(( $END - $START)); echo "Duración total: $DIFF segundos"; echo "$SEP" ) | yad --text-info --tail --title 'Arrancando trabajo 4 RDOR...' --height 400 --width 800 --fontname="Monospace 7" --wrap &




